function muscledata=getMineck_f(filename_,rowstrt_,rowend_,column_)
% getMineck
%   This is a function which reads in the muscle data from a Mineck file
%   and returns the requested data in 'muscledata' (which is a class). 
%
%   input:  filename_   -xls file to open
%           rowstrt_    -row a particular muscle starts on, e.g. lpca
%           rowend_     -the last row containing any muscle data for the
%                        particular muscle
%           column_     -column the averages start, should be about 8 or
%           'H'
%
%   returns:muscledata.xo   -origin x data array
%                     .yo   -origin y data array
%                     .zo   -origin z data array
%                     .xi   -insertion x data array
%                     .yi   -insertion y data array
%                     .zi   -insertion z data array
%                     .length   -lenght of bundle (array)
%                     .weight   -weight of bundle (array)
%                     .XSarea   -cross sectional area as calculated by
%                                Mineck
%
%       Sample use:  muscledata=getMineck('canine9.xls',28,111,8)
%
%   Eric Hunter, 20050104

% filename_='canine9.xls';
% rowstrt_=28;            % start of current muscle
% rowend_=111;            % end of current muscle
% column_=8;              % where x occurse


origin_=[rowstrt_:6:rowend_];
insertion=origin_+1;

try         % is EXCEL open?   
    channel = ddeinit('excel',filename_);
    range_=['r' num2str(origin_(1)) 'c1'];
    tmp_= ddereq(channel,range_,[1 1]); % Note the format array, first 1...
    % is default, second 1 is for text...
    % (0 for number)
    
catch       % open EXCEL
    tmp_=pwd;
    eval(['!' tmp_ '\' filename_ ' &'])
    disp('... waiting for excel to open...')
    pause(1.5),disp(' . '),pause(1.5),disp(' . '),pause(1.5),disp(' . '),
    pause(1.5),disp(' . '),pause(1),disp('...continuing...'),
    
    channel = ddeinit('excel',filename_);
    range_=['r' num2str(origin_(1)) 'c1'];
    tmp_= ddereq(channel,range_,[1 1]); % Note the format array, first 1...
    %  is default, second 1 is for text...
    %  (0 for number)    
end
muscledata.muscle_=tmp_(2:end-3);   % an extra space was at the end
muscledata.rghtOlft_=tmp_(1);       % right or left muscle

if column_==8
    
    for n=1:length(origin_)
        range_=['r' num2str(origin_(n)) 'c' num2str(column_)...
                ':r' num2str(origin_(n)) 'c' num2str(column_+9)];
        tmp_= ddereq(channel,range_);     %Calibration distance for SPL [cm]
        % assign origin positions
        muscledata.xo_(n)= tmp_(1);
        muscledata.yo_(n)=tmp_(2);
        muscledata.zo_(n)=tmp_(3);    
        % assign other properties
        muscledata.lngth_(n)=tmp_(4);
        muscledata.weight_(n)=tmp_(5);
        muscledata.XSarea_(n)=tmp_(6);
        muscledata.angleXY_(n)=tmp_(7);
        muscledata.angleXYadj_(n)=tmp_(8);,
        muscledata.angleYZ_(n)=tmp_(9);
        muscledata.angleYZadj_(n)=tmp_(10);,
        
        range_=['r' num2str(origin_(n)+1) 'c' num2str(column_)...
                ':r' num2str(origin_(n)+1) 'c' num2str(column_+2)];
        tmp_= ddereq(channel,range_);     %Calibration distance for SPL [cm]
        % assign insertion positions
        muscledata.xi_(n)= tmp_(1);
        muscledata.yi_(n)=tmp_(2);
        muscledata.zi_(n)=tmp_(3);   
        
    end
    
else
    origin_=[rowstrt_:rowend_];
    for n=1:length(origin_)
        
        range_=['r' num2str(origin_(n)) 'c' num2str(column_)...
                ':r' num2str(origin_(n)) 'c' num2str(column_+2)];
        tmp_= ddereq(channel,range_);     %Calibration distance for SPL [cm]
        % assign origin positions
        muscledata.xo_(n)=tmp_(1);
        muscledata.yo_(n)=tmp_(2);
        muscledata.zo_(n)=tmp_(3);  
    end
end   
