function plotBundles_f(xi,yi,zi,xo,yo,zo,xres,yres,figure_)
%PLOTBUNDLES_F Plots bundle info from origin and insertion information.
%
%  send arrays xo, yo, zo (origin data) and xi, yi, zi (insertion data) and
%  xres, yres (x and y resolution for surface)
%
%
%   eric.hunter 20050105


if exist('figure_')==0,figure_=100,end
figure(figure_)

ximin = min(xi); yimin = min(yi);
ximax = max(xi); yimax = max(yi); 
xomin = min(xo); yomin = min(yo);
xomax = max(xo); yomax = max(yo); 


% Define the range and spacing of the x- and y-coordinates,
% and then fit them into X and Y
xiv = linspace(ximin, ximax, xres);
yiv = linspace(yimin, yimax, yres);
[Xiinterp,Yiinterp] = meshgrid(xiv,yiv); 

xres=ceil(xres/2);
yres=ceil(yres/2);

xov = linspace(xomin, xomax, xres);
yov = linspace(yomin, yomax, yres);
[Xointerp,Yointerp] = meshgrid(xov,yov); 


% Calculate Z in the X-Y interpolation space, which is an 
% evenly spaced grid:
Ziinterp = griddata(xi,yi,zi,Xiinterp,Yiinterp,'cubic'); 
Zointerp = griddata(xo,yo,zo,Xointerp,Yointerp,'cubic'); 


% Generate the mesh plot (CONTOUR can also be used):
figure(figure_)
hold on
mesh(Xiinterp,Yiinterp,Ziinterp)
mesh(Xointerp,Yointerp,Zointerp)
plot3(xi,yi,zi,'.')
plot3(xo,yo,zo,'.')
for n=1:length(xi)
plot3([xi(n) xo(n)],[yi(n) yo(n)],[zi(n) zo(n)],':')
end
hold off
xlabel X; ylabel Y; zlabel Z;
% cnt_=0;
% [N,M]=size(Xiinterp);
% for n=1:N
%     for m=1:M
%         if isfinite(Ziinterp(n,m))
%             cnt_=cnt_+1;
%             XYZ_(cnt_,:)=[Xiinterp(n,m),Yiinterp(n,m),Ziinterp(n,m)];
%         end
%     end
% end
% 

