function plotBundles_f(xi,yi,zi,xres,yres,figure_)
%PLOTBUNDLES_F Plots bundle info from origin and insertion information.
%
%  send arrays xo, yo, zo (origin data) and xi, yi, zi (insertion data) and
%  xres, yres (x and y resolution for surface)
%
%
%   eric.hunter 20050105


if exist('figure_')==0,figure_=100,end

ximin = min(xi); yimin = min(yi);
ximax = max(xi); yimax = max(yi); 


% Define the range and spacing of the x- and y-coordinates,
% and then fit them into X and Y
xiv = linspace(ximin, ximax, xres);
yiv = linspace(yimin, yimax, yres);
[Xiinterp,Yiinterp] = meshgrid(xiv,yiv); 


% Calculate Z in the X-Y interpolation space, which is an 
% evenly spaced grid:
Ziinterp = griddata(xi,yi,zi,Xiinterp,Yiinterp,'cubic'); 


% Generate the mesh plot (CONTOUR can also be used):
figure(figure_)
hold on
mesh(Xiinterp,Yiinterp,Ziinterp)
plot3(xi,yi,zi,'.')
hold off
xlabel X; ylabel Y; zlabel Z;
cnt_=0;
[N,M]=size(Xiinterp);


